@@ -1,4 +1,3 @@
-{-# LANGUAGE CPP #-}
 -----------------------------------------------------------------------------
 -- |
 -- Copyright   :  (C) 2013-2015 Edward Kmett and Anthony Cowley
@@ -16,16 +15,8 @@ module Linear.Binary
   , getLinear
   ) where
 
-#if __GLASGOW_HASKELL__ < 710
-import Control.Applicative
-#endif
 import Data.Binary
-#if __GLASGOW_HASKELL__ < 710
-import Data.Foldable (Foldable, traverse_)
-import Data.Traversable (Traversable, sequenceA)
-#else
 import Data.Foldable (traverse_)
-#endif
 
 -- | Serialize a linear type.
 putLinear :: (Binary a, Foldable t) => t a -> Put
