@@ -9,22 +9,6 @@
 {-# LANGUAGE DataKinds #-}
 {-# LANGUAGE DeriveLift #-}
 
-#ifndef MIN_VERSION_hashable
-#define MIN_VERSION_hashable(x,y,z) 1
-#endif
-
-#ifndef MIN_VERSION_vector
-#define MIN_VERSION_vector(x,y,z) 1
-#endif
-
-#ifndef MIN_VERSION_transformers
-#define MIN_VERSION_transformers(x,y,z) 1
-#endif
-
-#ifndef MIN_VERSION_base
-#define MIN_VERSION_base(x,y,z) 1
-#endif
-
 -----------------------------------------------------------------------------
 -- |
 -- Copyright   :  (C) 2012-2015 Edward Kmett
@@ -76,7 +60,8 @@ import Linear.Metric
 import Linear.Epsilon
 import Linear.Vector
 import Linear.V
-import System.Random (Random(..))
+import System.Random (Random(..), Uniform)
+import System.Random.Stateful (UniformRange(..))
 import Prelude hiding (sum)
 
 -- $setup
@@ -111,6 +96,11 @@ instance Random (V0 a) where
   randomRs _ _ = repeat V0
   randoms _ = repeat V0
 
+instance Uniform (V0 a) where
+
+instance UniformRange (V0 a) where
+  uniformRM (_, _) _ = pure V0
+
 instance Serial1 V0 where
   serializeWith _ = serialize
   deserializeWith _ = deserialize
